@@ -51,7 +51,6 @@
 #include "dlg-color-balance.h"
 #include "dlg-preferences.h"
 #include "dlg-rename-series.h"
-#include "dlg-save-image.h"
 #include "dlg-scale-image.h"
 #include "fullscreen.h"
 #include "gconf-utils.h"
@@ -70,12 +69,14 @@
 #include "gth-folder-selection-dialog.h"
 
 #define MAX_NAME_LEN 1024
+#define DEF_CONFIRM_DEL TRUE
 
 typedef enum {
 	WALLPAPER_ALIGN_TILED     = 0,
 	WALLPAPER_ALIGN_CENTERED  = 1,
 	WALLPAPER_ALIGN_STRETCHED = 2,
-	WALLPAPER_ALIGN_SCALED    = 3
+	WALLPAPER_ALIGN_SCALED    = 3,
+	WALLPAPER_NONE            = 4
 } WallpaperAlign;
 
 
@@ -102,7 +103,7 @@ file_new_window_command_impl (BonoboUIComponent *uic,
 					NULL);	
 
 	if (location != NULL) {
-		eel_gconf_set_locale_string (PREF_STARTUP_LOCATION, location);
+		preferences_set_startup_location (location);
 		g_free (location);
 	}
 
@@ -177,39 +178,15 @@ image_open_with_command_impl (BonoboUIComponent *uic,
 }
 
 
-static void
-image_saved_func (char     *filename,
-		  gpointer  data)
-{
-	GThumbWindow *window = data;
-	if (filename != NULL) 
-		window_load_image (window, filename);
-}
-
-
 void 
 file_save_command_impl (BonoboUIComponent *uic, 
 			gpointer           user_data, 
 			const gchar       *verbname)
 {
 	GThumbWindow *window = user_data;
-	char         *current_folder = NULL;
+	ImageViewer  *viewer = IMAGE_VIEWER (window->viewer);
 
-	if (window->image_path != NULL)
-		current_folder = g_strdup (window->image_path);
-
-	else if (window->dir_list->path != NULL)
-		current_folder = g_strconcat (window->dir_list->path,
-					      "/", 
-					      NULL);
-
-	dlg_save_image (GTK_WINDOW (window->app), 
-			current_folder,
-			image_viewer_get_current_pixbuf (IMAGE_VIEWER (window->viewer)),
-			image_saved_func,
-			window);
-
-	g_free (current_folder);
+	window_save_pixbuf (window, image_viewer_get_current_pixbuf (viewer));
 }
 
 
@@ -267,7 +244,7 @@ rename_file (GThumbWindow *window,
 		
 	old_path = list->data;
 	old_name = file_name_from_path (old_path);
-	old_name_utf8 = g_locale_to_utf8 (old_name, -1, NULL, NULL, NULL);
+	old_name_utf8 = g_filename_to_utf8 (old_name, -1, NULL, NULL, NULL);
 
 	new_name_utf8 = _gtk_request_dialog_run (GTK_WINDOW (window->app),
 						 GTK_DIALOG_MODAL,
@@ -281,13 +258,13 @@ rename_file (GThumbWindow *window,
 	if (new_name_utf8 == NULL) 
 		return;
 
-	new_name = g_locale_from_utf8 (new_name_utf8, -1, 0, 0, 0);
+	new_name = g_filename_from_utf8 (new_name_utf8, -1, 0, 0, 0);
 	g_free (new_name_utf8);
 
 	if (strchr (new_name, '/') != NULL) {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       _("The name \"%s\" is not valid because it contains the character \"/\". " "Please use a different name."), utf8_name);
 		g_free (utf8_name);
@@ -308,7 +285,7 @@ rename_file (GThumbWindow *window,
 		char      *utf8_name;
 		int        r;
 
-		utf8_name = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
 		message = g_strdup_printf (_("An image named \"%s\" is already present. " "Do you want to overwrite it?"), utf8_name);
 		g_free (utf8_name);
 
@@ -334,7 +311,7 @@ rename_file (GThumbWindow *window,
 	if (strcmp (old_path, new_path) == 0) {
 		char *utf8_path;
 
-		utf8_path = g_locale_to_utf8 (old_path, -1, NULL, NULL, NULL);
+		utf8_path = g_filename_to_utf8 (old_path, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       _("Could not rename the image \"%s\": %s"),
 				       utf8_path,
@@ -349,7 +326,7 @@ rename_file (GThumbWindow *window,
 	} else {
 		char *utf8_path;
 
-		utf8_path = g_locale_to_utf8 (old_path, -1, NULL, NULL, NULL);
+		utf8_path = g_filename_to_utf8 (old_path, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       _("Could not rename the image \"%s\": %s"),
 				       utf8_path,
@@ -432,18 +409,46 @@ duplicate_file (GThumbWindow *window,
 	g_free (old_name_no_ext);
 
 	if (file_copy (old_path, new_path)) {
+		GList *file_list;
+
 		cache_copy (old_path, new_path);
 		comment_copy (old_path, new_path);
 
-	} else {
-		char *utf8_path;
+		all_windows_remove_monitor ();
 
-		utf8_path = g_locale_to_utf8 (old_path, -1, NULL, NULL, NULL);
-		_gtk_error_dialog_run (GTK_WINDOW (window->app),
-				       _("Could not duplicate the image \"%s\": %s"),
+		file_list = g_list_prepend (NULL, new_path);
+		all_windows_notify_files_created (file_list);
+		g_list_free (file_list);
+
+		all_windows_add_monitor ();
+
+	} else {
+		char      *utf8_path;
+		char      *msg;
+		GtkWidget *d;
+		int        r;
+
+		utf8_path = g_filename_to_utf8 (old_path, -1, NULL, NULL, NULL);
+		msg = g_strdup_printf (_("Could not duplicate the image \"%s\": %s"),
 				       utf8_path,
 				       errno_to_string ());
 		g_free (utf8_path);
+
+		d = _gtk_yesno_dialog_new (GTK_WINDOW (window->app),
+					   GTK_DIALOG_MODAL,
+					   msg,
+					   _("Stop"),
+					   _("Continue"));
+		g_free (msg);
+
+		r = gtk_dialog_run (GTK_DIALOG (d));
+		gtk_widget_destroy (GTK_WIDGET (d));
+
+		if (r != GTK_RESPONSE_YES) {
+			g_free (new_path);
+			g_free (new_name);
+			return;
+		}
 	}
 
 	g_free (new_name);
@@ -754,7 +759,7 @@ image_delete_from_catalog_command_impl (BonoboUIComponent *uic,
 	if (window->image_path == NULL)
 		return;
 
-	if (! eel_gconf_get_boolean (PREF_CONFIRM_DELETION)) {
+	if (! eel_gconf_get_boolean (PREF_CONFIRM_DELETION, DEF_CONFIRM_DEL)) {
 		list = g_list_prepend (NULL, g_strdup (window->image_path));
 		real_remove_from_catalog (window, list);
 		/* the list is deallocated in real_remove_from_catalog. */
@@ -798,7 +803,7 @@ edit_remove_from_catalog_command_impl (BonoboUIComponent *uic,
 	GtkWidget    *dialog;
 	int           r;
 
-	if (! eel_gconf_get_boolean (PREF_CONFIRM_DELETION)) {
+	if (! eel_gconf_get_boolean (PREF_CONFIRM_DELETION, DEF_CONFIRM_DEL)) {
 		remove_selection_from_catalog (window);
 		return;
 	}
@@ -886,13 +891,13 @@ create_new_folder_or_library (GThumbWindow *window,
 	if (new_name_utf8 == NULL) 
 		return;
 
-	new_name = g_locale_from_utf8 (new_name_utf8, -1, 0, 0, 0);
+	new_name = g_filename_from_utf8 (new_name_utf8, -1, 0, 0, 0);
 	g_free (new_name_utf8);
 
 	if (strchr (new_name, '/') != NULL) {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       _("The name \"%s\" is not valid because it contains the character \"/\". " "Please use a different name."), utf8_name);
 		g_free (utf8_name);
@@ -908,7 +913,7 @@ create_new_folder_or_library (GThumbWindow *window,
 	if (path_is_dir (new_path)) {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       _("The name \"%s\" is already used. " "Please use a different name."), utf8_name);
 		g_free (utf8_name);
@@ -917,7 +922,7 @@ create_new_folder_or_library (GThumbWindow *window,
 	} else {
 		char *utf8_path;
 
-		utf8_path = g_locale_to_utf8 (new_path, -1, NULL, NULL, NULL);
+		utf8_path = g_filename_to_utf8 (new_path, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
                                        str_error,
                                        utf8_path,
@@ -984,7 +989,7 @@ folder_rename (GThumbWindow *window,
 	char         *parent_path;
 
 	old_name = file_name_from_path (old_path);
-	old_name_utf8 = g_locale_to_utf8 (old_name, -1, NULL, NULL, NULL);
+	old_name_utf8 = g_filename_to_utf8 (old_name, -1, NULL, NULL, NULL);
 
 	new_name_utf8 = _gtk_request_dialog_run (GTK_WINDOW (window->app),
 						 GTK_DIALOG_MODAL,
@@ -998,13 +1003,13 @@ folder_rename (GThumbWindow *window,
 	if (new_name_utf8 == NULL) 
 		return;
 
-	new_name = g_locale_from_utf8 (new_name_utf8, -1, 0, 0, 0);
+	new_name = g_filename_from_utf8 (new_name_utf8, -1, 0, 0, 0);
 	g_free (new_name_utf8);
 
 	if (strchr (new_name, '/') != NULL) {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       _("The name \"%s\" is not valid because it contains the character \"/\". " "Please use a different name."), utf8_name);
 		g_free (utf8_name);
@@ -1024,7 +1029,7 @@ folder_rename (GThumbWindow *window,
 	if (strcmp (old_path, new_path) == 0) {
 		char *utf8_path;
 		
-		utf8_path = g_locale_to_utf8 (old_path, -1, NULL, NULL, NULL);
+		utf8_path = g_filename_to_utf8 (old_path, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       _("Could not rename the folder \"%s\": %s"),
 				       utf8_path,
@@ -1034,39 +1039,42 @@ folder_rename (GThumbWindow *window,
 	} else if (path_is_dir (new_path)) {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       _("The name \"%s\" is already used. " "Please use a different name."), utf8_name);
 		g_free (utf8_name);
 
-	} else if (rename (old_path, new_path) == 0) { 
-		char *old_cache_path, *new_cache_path;
-
-		/* Update cache info. */
-
-		/* Comment cache. */
-
-		old_cache_path = comments_get_comment_dir (old_path, TRUE);
+	} else {
+		char *old_cache_path = NULL;
+		
+		old_cache_path = comments_get_comment_dir (old_path, TRUE, TRUE);
 		if (! path_is_dir (old_cache_path)) {
 			g_free (old_cache_path);
-			old_cache_path = comments_get_comment_dir (old_path, FALSE);
+			old_cache_path = comments_get_comment_dir (old_path, FALSE, TRUE);
 		}
-		new_cache_path = comments_get_comment_dir (new_path, TRUE);
-		rename (old_cache_path, new_cache_path);
+
+		if (rename (old_path, new_path) == 0) { 
+			char *new_cache_path;
+			
+			/* Comment cache. */
+			
+			new_cache_path = comments_get_comment_dir (new_path, TRUE, TRUE);
+			rename (old_cache_path, new_cache_path);
+			g_free (new_cache_path);
+			
+			all_windows_notify_directory_rename (old_path, new_path);
+
+		} else {
+			char *utf8_path;
+			utf8_path = g_filename_to_utf8 (old_path, -1, NULL, NULL, NULL);
+			_gtk_error_dialog_run (GTK_WINDOW (window->app),
+					       _("Could not rename the folder \"%s\": %s"),
+					       utf8_path,
+					       errno_to_string ());
+			g_free (utf8_path);
+		}
+
 		g_free (old_cache_path);
-		g_free (new_cache_path);
-
-		all_windows_notify_directory_rename (old_path, new_path);
-
-	} else {
-		char *utf8_path;
-
-		utf8_path = g_locale_to_utf8 (old_path, -1, NULL, NULL, NULL);
-		_gtk_error_dialog_run (GTK_WINDOW (window->app),
-                                       _("Could not rename the folder \"%s\": %s"),
-                                       utf8_path,
-                                       errno_to_string ());
-		g_free (utf8_path);
 	}
 
 	all_windows_add_monitor ();
@@ -1130,7 +1138,7 @@ folder_delete__continue2 (GnomeVFSResult result,
 		char       *utf8_name;
 		
 		message = _("Could not delete the folder \"%s\": %s");
-		utf8_name = g_locale_to_utf8 (file_name_from_path (fddata->path), -1, 0, 0, 0);
+		utf8_name = g_filename_to_utf8 (file_name_from_path (fddata->path), -1, 0, 0, 0);
 
 		_gtk_error_dialog_run (GTK_WINDOW (fddata->window->app),
 				       message, 
@@ -1152,25 +1160,31 @@ folder_delete__continue (GnomeVFSResult result,
 	FolderDeleteData *fddata = data;
 
 	if (result == GNOME_VFS_ERROR_NOT_FOUND) {
-		GtkWidget *d;
-		char      *utf8_name;
-		char      *message;
-		int        r;
+		int r = GTK_RESPONSE_YES;
 
-		utf8_name = g_locale_to_utf8 (file_name_from_path (fddata->path), -1, 0, 0, 0);
-		message = g_strdup_printf (_("\"%s\" cannot be moved to the Trash. Do you want to delete it permanently?"), utf8_name);
+		if (eel_gconf_get_boolean (PREF_MSG_CANNOT_MOVE_TO_TRASH, TRUE)) {
+			GtkWidget *d;
+			char      *utf8_name;
+			char      *message;
 
-		d = _gtk_yesno_dialog_new (GTK_WINDOW (fddata->window->app),
-					   GTK_DIALOG_MODAL,
-					   message,
-					   GTK_STOCK_CANCEL,
-					   GTK_STOCK_DELETE);
+			utf8_name = g_filename_to_utf8 (file_name_from_path (fddata->path), -1, 0, 0, 0);
+			message = g_strdup_printf (_("\"%s\" cannot be moved to the Trash. Do you want to delete it permanently?"), utf8_name);
 
-		g_free (message);
-		g_free (utf8_name);
+			d = _gtk_yesno_dialog_with_checkbutton_new (
+				    GTK_WINDOW (fddata->window->app),
+				    GTK_DIALOG_MODAL,
+				    message,
+				    GTK_STOCK_CANCEL,
+				    GTK_STOCK_DELETE,
+				    _("_Do not display this message again"),
+				    PREF_MSG_CANNOT_MOVE_TO_TRASH);
 
-		r = gtk_dialog_run (GTK_DIALOG (d));
-		gtk_widget_destroy (GTK_WIDGET (d));
+			g_free (message);
+			g_free (utf8_name);
+		
+			r = gtk_dialog_run (GTK_DIALOG (d));
+			gtk_widget_destroy (GTK_WIDGET (d));
+		} 
 
 		if (r == GTK_RESPONSE_YES) 
 			dlg_folder_delete (fddata->window, 
@@ -1264,7 +1278,7 @@ folder_copy__continue (GnomeVFSResult result,
 		char       *utf8_name;
 		
 		message = _("Could not copy the folder \"%s\": %s");
-		utf8_name = g_locale_to_utf8 (file_name_from_path (path), -1, 0, 0, 0);
+		utf8_name = g_filename_to_utf8 (file_name_from_path (path), -1, 0, 0, 0);
 		
 		_gtk_error_dialog_run (NULL,
 				       message, 
@@ -1323,7 +1337,7 @@ folder_copy__response_cb (GObject *object,
 	if (strcmp (old_path, new_path) == 0) {
 		char *utf8_path;
 		
-		utf8_path = g_locale_to_utf8 (old_path, -1, NULL, NULL, NULL);
+		utf8_path = g_filename_to_utf8 (old_path, -1, NULL, NULL, NULL);
 
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       message,
@@ -1334,7 +1348,7 @@ folder_copy__response_cb (GObject *object,
 	} else if (strncmp (old_path, new_path, strlen (old_path)) == 0) {
 		char *utf8_path;
 		
-		utf8_path = g_locale_to_utf8 (old_path, -1, NULL, NULL, NULL);
+		utf8_path = g_filename_to_utf8 (old_path, -1, NULL, NULL, NULL);
 
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       message,
@@ -1345,7 +1359,7 @@ folder_copy__response_cb (GObject *object,
 	} else if (path_is_dir (new_path)) {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (dir_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (dir_name, -1, NULL, NULL, NULL);
 
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       message,
@@ -1363,45 +1377,51 @@ folder_copy__response_cb (GObject *object,
 				 folder_copy__continue, 
 				 g_strdup (old_path));
 
-	} else if (rename (old_path, new_path) == 0) { 
-		char *old_cache_path, *new_cache_path;
-
-		/* moving folders on the same file system can be implemeted 
-		 * with rename, which is faster. */
+	} else {
+		char *old_cache_path = NULL;
 
 		/* Comment cache. */
-
-		old_cache_path = comments_get_comment_dir (old_path, TRUE);
+			
+		old_cache_path = comments_get_comment_dir (old_path, TRUE, TRUE);
 		if (! path_is_dir (old_cache_path)) {
 			g_free (old_cache_path);
-			old_cache_path = comments_get_comment_dir (old_path, FALSE);
+			old_cache_path = comments_get_comment_dir (old_path, FALSE, TRUE);
 		}
-		new_cache_path = comments_get_comment_dir (new_path, TRUE);
 
-		if (path_is_dir (old_cache_path)) {
-			char *parent_dir;
+		if (rename (old_path, new_path) == 0) { 
+			char *new_cache_path;
 
-			parent_dir = remove_level_from_path (new_cache_path);
-			ensure_dir_exists (parent_dir, 0755);
-			g_free (parent_dir);
+			/* moving folders on the same file system can be implemeted 
+			 * with rename, which is faster. */
 
-			rename (old_cache_path, new_cache_path);
+			new_cache_path = comments_get_comment_dir (new_path, TRUE, TRUE);
+			
+			if (path_is_dir (old_cache_path)) {
+				char *parent_dir;
+				
+				parent_dir = remove_level_from_path (new_cache_path);
+				ensure_dir_exists (parent_dir, 0755);
+				g_free (parent_dir);
+				
+				rename (old_cache_path, new_cache_path);
+			}
+
+			g_free (new_cache_path);
+
+			all_windows_notify_directory_rename (old_path, new_path);
+
+		} else {
+			char *utf8_path;
+
+			utf8_path = g_filename_to_utf8 (old_path, -1, NULL, NULL, NULL);
+			_gtk_error_dialog_run (GTK_WINDOW (window->app),
+					       message,
+					       utf8_path,
+					       errno_to_string ());
+			g_free (utf8_path);
 		}
 
 		g_free (old_cache_path);
-		g_free (new_cache_path);
-
-		all_windows_notify_directory_rename (old_path, new_path);
-
-	} else {
-		char *utf8_path;
-
-		utf8_path = g_locale_to_utf8 (old_path, -1, NULL, NULL, NULL);
-		_gtk_error_dialog_run (GTK_WINDOW (window->app),
-				       message,
-                                       utf8_path,
-                                       errno_to_string ());
-		g_free (utf8_path);
 	}
 
 	g_free (dest_dir);
@@ -1546,7 +1566,7 @@ catalog_rename (GThumbWindow *window,
 		name_only = remove_extension_from_path (file_name_from_path (catalog_path));
 	else
 		name_only = g_strdup (file_name_from_path (catalog_path));
-	name_only_utf8 = g_locale_to_utf8 (name_only, -1, NULL, NULL, NULL);
+	name_only_utf8 = g_filename_to_utf8 (name_only, -1, NULL, NULL, NULL);
 
 	new_name_utf8 = _gtk_request_dialog_run (GTK_WINDOW (window->app),
 						 GTK_DIALOG_MODAL,
@@ -1562,13 +1582,13 @@ catalog_rename (GThumbWindow *window,
 		return;
 	}
 
-	new_name = g_locale_from_utf8 (new_name_utf8, -1, 0, 0, 0);
+	new_name = g_filename_from_utf8 (new_name_utf8, -1, 0, 0, 0);
 	g_free (new_name_utf8);
 
 	if (strchr (new_name, '/') != NULL) {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       _("The name \"%s\" is not valid because it contains the character \"/\". " "Please use a different name."), utf8_name);
 
@@ -1590,7 +1610,7 @@ catalog_rename (GThumbWindow *window,
 	if (path_is_file (new_catalog_path)) {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app), 
 				       _("The name \"%s\" is already used. " "Please use a different name."), utf8_name);
 		g_free (utf8_name);
@@ -1601,7 +1621,7 @@ catalog_rename (GThumbWindow *window,
 	} else {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (name_only, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (name_only, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app), 
                                        is_dir ? _("Could not rename the library \"%s\": %s") : _("Could not rename the catalog \"%s\": %s"),
                                        utf8_name,
@@ -1657,13 +1677,13 @@ edit_current_catalog_new_command_impl (BonoboUIComponent *uic,
 	if (new_name_utf8 == NULL) 
 		return;
 
-	new_name = g_locale_from_utf8 (new_name_utf8, -1, 0, 0, 0);
+	new_name = g_filename_from_utf8 (new_name_utf8, -1, 0, 0, 0);
 	g_free (new_name_utf8);
 
 	if (strchr (new_name, '/') != NULL) {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app),
 				       _("The name \"%s\" is not valid because it contains the character \"/\". " "Please use a different name."), utf8_name);
 
@@ -1682,7 +1702,7 @@ edit_current_catalog_new_command_impl (BonoboUIComponent *uic,
 	if (path_is_file (new_catalog_path)) {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app), 
 				       _("The name \"%s\" is already used. " "Please use a different name."), utf8_name);
 		g_free (utf8_name);
@@ -1693,7 +1713,7 @@ edit_current_catalog_new_command_impl (BonoboUIComponent *uic,
 	} else {
 		char *utf8_name;
 
-		utf8_name = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_name = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (window->app), 
                                        _("Could not create the catalog \"%s\": %s"), 
                                        utf8_name,
@@ -1753,7 +1773,7 @@ catalog_delete (GThumbWindow *window,
 
 	/* Always ask before deleting folders. */
 
-	if (! path_is_dir (catalog_path) && ! eel_gconf_get_boolean (PREF_CONFIRM_DELETION)) {
+	if (! path_is_dir (catalog_path) && ! eel_gconf_get_boolean (PREF_CONFIRM_DELETION, DEF_CONFIRM_DEL)) {
 		real_catalog_delete (window);
 		return;
 	}
@@ -2206,11 +2226,6 @@ view_zoom_fit_command_impl (BonoboUIComponent *uic,
 	GThumbWindow *window = user_data;
 	ImageViewer  *viewer = IMAGE_VIEWER (window->viewer);
 
-	if (window->freeze_toggle_handler > 0) {
-		window->freeze_toggle_handler--;
-		return;
-	}
-
 	if (viewer->zoom_fit) 
 		viewer->zoom_fit = FALSE;
 	else 
@@ -2233,52 +2248,6 @@ view_step_ani_command_impl (BonoboUIComponent *uic,
 }
 
 
-void 
-view_show_folders_command_impl (BonoboUIComponent *uic, 
-				gpointer           user_data, 
-				const gchar       *verbname)
-{
-	GThumbWindow *window = user_data;
-	
-	if (window->freeze_toggle_handler > 0) {
-		window->freeze_toggle_handler--;
-		return;
-	}
-	
-	if (! GTK_WIDGET_VISIBLE (window->app))
-		return;
-
-	if ((window->sidebar_visible) 
-	    && (window->sidebar_content == GTH_SIDEBAR_DIR_LIST))
-		window_hide_sidebar (window);
-	else
-		window_set_sidebar_content (window, GTH_SIDEBAR_DIR_LIST);
-}
-
-
-void 
-view_show_catalogs_command_impl (BonoboUIComponent *uic, 
-				 gpointer           user_data, 
-				 const gchar       *verbname)
-{
-	GThumbWindow *window = user_data;
-
-	if (window->freeze_toggle_handler > 0) {
-		window->freeze_toggle_handler--;
-		return;
-	}
-
-	if (! GTK_WIDGET_VISIBLE (window->app))
-		return;
-
-	if ((window->sidebar_visible) 
-	    && (window->sidebar_content == GTH_SIDEBAR_CATALOG_LIST))
-		window_hide_sidebar (window);
-	else
-		window_set_sidebar_content (window, GTH_SIDEBAR_CATALOG_LIST);
-}
-
-
 void 
 view_fullscreen_command_impl (BonoboUIComponent *uic, 
 			      gpointer           user_data, 
@@ -2286,11 +2255,6 @@ view_fullscreen_command_impl (BonoboUIComponent *uic,
 {
 	GThumbWindow *window = user_data;
 
-	if (window->freeze_toggle_handler > 0) {
-		window->freeze_toggle_handler--;
-		return;
-	}
-
 	if (! window->fullscreen)
 		fullscreen_start (fullscreen, window);
 	else
@@ -2523,7 +2487,11 @@ set_as_wallpaper (GThumbWindow   *window,
 	case WALLPAPER_ALIGN_SCALED:
 		options = "scaled";
 		break;
+	case WALLPAPER_NONE:
+		options = "none";
+		break;
 	}
+
 	gconf_client_set_string (client, 
 				 "/desktop/gnome/background/picture_options", 
 				 options,
@@ -2588,6 +2556,8 @@ wallpaper_restore_command_impl (BonoboUIComponent *uic,
 		align_type = WALLPAPER_ALIGN_STRETCHED;
 	else if (strcmp (preferences.wallpaperAlign, "scaled") == 0)
 		align_type = WALLPAPER_ALIGN_SCALED;
+	else if (strcmp (preferences.wallpaperAlign, "none") == 0)
+		align_type = WALLPAPER_NONE;
 
 	set_as_wallpaper (window, 
 			  preferences.wallpaper,
