@@ -73,6 +73,7 @@ typedef struct {
 	int           rot_type;    /* 0, 90 ,180, 270 */
 	int           tran_type;   /* mirror, flip */
 	GList        *file_list;
+	GList        *files_changed_list;
 	GList        *current_image;
 	GtkWidget    *viewer;
 } DialogData;
@@ -83,6 +84,13 @@ static void
 destroy_cb (GtkWidget  *widget, 
 	    DialogData *data)
 {
+	if (data->files_changed_list != NULL) {
+		all_windows_notify_files_changed (data->files_changed_list);
+		path_list_free (data->files_changed_list);
+	}
+
+	all_windows_add_monitor ();
+
 	file_data_list_free (data->file_list);
 	g_object_unref (data->gui);
 	g_free (data);
@@ -237,24 +245,46 @@ static void
 apply_tran (DialogData *data,
 	    GList      *current_image)
 {
-	FileData   *fd = current_image->data;
-	int         rot_type = data->rot_type; 
-	int         tran_type = data->tran_type; 
-	char       *line;
-	char       *tmp1, *tmp2;
-	static int  count = 0;
-	GError     *err = NULL;
-	GtkWindow  *parent = GTK_WINDOW (data->dialog);
+	FileData    *fd = current_image->data;
+	char        *dir;
+	struct stat  buf;
+	int          rot_type = data->rot_type; 
+	int          tran_type = data->tran_type; 
+	char        *line;
+	char        *tmp1, *tmp2;
+	static int   count = 0;
+	GError      *err = NULL;
+	GtkWindow   *parent = GTK_WINDOW (data->dialog);
 #ifdef HAVE_LIBJPEG
-	JXFORM_CODE transf;
+	JXFORM_CODE  transf;
 #else
-	char       *command;
+	char        *command;
 #endif
-	char       *e1, *e2;
+	char        *e1, *e2;
 
 	if ((rot_type == TRAN_ROTATE_0) && (tran_type == TRAN_NONE))
 		return;
 
+	/* Check directory permissions. */
+	
+	dir = remove_level_from_path (fd->path);
+	if (access (dir, R_OK | W_OK | X_OK) != 0) {
+		char *utf8_path;
+		utf8_path = g_filename_to_utf8 (dir, -1, NULL, NULL, NULL);
+		_gtk_error_dialog_run (GTK_WINDOW (data->dialog),
+				       _("You don't have the right permissions to create images in the folder \"%s\""),
+				       utf8_path);
+		g_free (utf8_path);
+		g_free (dir);
+		return;
+	} 
+	
+	g_free (dir);
+
+	/**/
+
+	stat (fd->path, &buf);
+
 	if (rot_type == TRAN_ROTATE_0)
 		tmp1 = g_strdup (fd->path);
 	else {
@@ -390,18 +420,17 @@ apply_tran (DialogData *data,
 		_gtk_error_dialog_from_gerror_run (parent, &err);
 
 	} else {
-		GList *list;
-
 #ifdef HAVE_LIBEXIF
 		if ((rot_type == TRAN_ROTATE_90) || (rot_type == TRAN_ROTATE_270))
 			swap_xy_exif_fields (fd->path);
 #endif
 
-		list = g_list_prepend (NULL, fd->path);
-		all_windows_notify_files_changed (list);
-		g_list_free (list);
+		data->files_changed_list = g_list_prepend (data->files_changed_list, 
+							   g_strdup (fd->path));
 	}
 
+	chmod (fd->path, buf.st_mode);
+
 	g_free (e1);
 	g_free (e2);
 	g_free (line);
@@ -447,7 +476,7 @@ ok_clicked (GtkWidget  *button,
 		for (scan = data->current_image; scan; scan = scan->next) {
 			FileData *fd = scan->data;
 
-			_gtk_label_set_locale_text (GTK_LABEL (label), fd->name);
+			_gtk_label_set_filename_text (GTK_LABEL (label), fd->name);
 			gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (bar),
 						       (gdouble) i / n);
 
@@ -619,7 +648,7 @@ help_cb (GtkWidget  *widget,
 	GError *err;
 
 	err = NULL;  
-	gnome_help_display ("gthumb", "rotate-jpeg", &err);
+	gnome_help_display ("gthumb", "gthumb-rotate-jpeg", &err);
 	
 	if (err != NULL) {
 		GtkWidget *dialog;
@@ -687,7 +716,7 @@ dlg_jpegtran (GThumbWindow *window)
 
 	/**/
 
-	data = g_new (DialogData, 1);
+	data = g_new0 (DialogData, 1);
 
 	data->file_list = list;
 	data->current_image = list;
@@ -791,6 +820,8 @@ dlg_jpegtran (GThumbWindow *window)
 
 	/* Run dialog. */
 
+	all_windows_remove_monitor ();
+
 	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (window->app));
 	gtk_window_set_modal (GTK_WINDOW (data->dialog), TRUE); 
 	gtk_widget_show_all (data->dialog);
