@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,8 +50,6 @@ static PangoRectangle  bounds;
 static GtkWidget      *popup_window = NULL;
 static GtkWidget      *prop_button = NULL;
 static FullScreen     *current_fullscreen;
-static int             main_window_x;
-static int             main_window_y;
 
 
 static void
@@ -163,12 +161,12 @@ render_frame (GdkDrawable    *drawable,
 
 
 static char *
-escape_locale_text (const char *text) 
+escape_filename (const char *text) 
 {
 	char *utf8_text;
 	char *escaped_text;
 
-	utf8_text = g_locale_to_utf8 (text, -1, NULL, NULL, NULL);
+	utf8_text = g_filename_to_utf8 (text, -1, NULL, NULL, NULL);
 	g_return_val_if_fail (utf8_text != NULL, NULL);
 	
 	escaped_text = g_markup_escape_text (utf8_text, -1);
@@ -206,11 +204,11 @@ get_file_info (GThumbWindow *window)
 	char       *file_size_txt;
 	int         zoom;
 	char       *file_info;
-	char        time_txt[50];
+	char        time_txt[50], *utf8_time_txt;
 	time_t      timer;
 	struct tm  *tm;
 
-	e_filename = escape_locale_text (file_name_from_path (window->image_path));
+	e_filename = escape_filename (file_name_from_path (window->image_path));
 
 	width = image_viewer_get_image_width (IMAGE_VIEWER (window->viewer));
 	height = image_viewer_get_image_height (IMAGE_VIEWER (window->viewer));
@@ -223,13 +221,17 @@ get_file_info (GThumbWindow *window)
 	timer = get_file_mtime (window->image_path);
 	tm = localtime (&timer);
 	strftime (time_txt, 50, _("%d %B %Y, %H:%M"), tm);
+	utf8_time_txt = g_locale_to_utf8 (time_txt, -1, 0, 0, 0);
 
-	file_info = g_strdup_printf ("%s\n%s (%d%%) - %s - %s ",
+	file_info = g_strdup_printf ("%d/%d - <tt>%s</tt>\n<i>%s (%d%%) - %s - %s </i>",
+				     gth_file_list_pos_from_path (window->file_list, window->image_path) + 1,
+				     gth_file_list_get_length (window->file_list),
 				     e_filename,
 				     size_txt,
 				     zoom,
 				     file_size_txt,
-				     time_txt);
+				     utf8_time_txt);
+	g_free (utf8_time_txt);
 	g_free (e_filename);
 	g_free (size_txt);
 	g_free (file_size_txt);
@@ -291,10 +293,10 @@ show_comment_on_image (GThumbWindow *window,
 	file_info = get_file_info (window);
 
 	if (comment == NULL)
-		marked_text = g_strdup_printf ("<i>%s</i>", file_info);
+		marked_text = g_strdup (file_info); /*g_strdup_printf ("<i>%s</i>", file_info);*/
 	else {
 		e_comment = g_markup_escape_text (comment, -1);
-		marked_text = g_strdup_printf ("<b>%s</b>\n<i>%s</i>", 
+		marked_text = g_strdup_printf ("<b>%s</b>\n%s", 
 					       e_comment, 
 					       file_info);
 		g_free (e_comment);
@@ -432,6 +434,7 @@ image_key_press_cb (GtkWidget   *widget,
 	case GDK_Escape:
 	case GDK_q:
 	case GDK_v:
+	case GDK_f:
 	case GDK_F11:
 		fullscreen_stop (fullscreen);
 		break;
@@ -565,8 +568,8 @@ image_key_press_cb (GtkWidget   *widget,
 		break;
 
 		/* Flip image. */
-	case GDK_f:
-	case GDK_F:
+	case GDK_l:
+	case GDK_L:
 		alter_image_flip_command_impl (NULL, window, NULL);
 		break;
 
@@ -953,11 +956,7 @@ fullscreen_start (FullScreen   *fullscreen,
 
 	current_fullscreen = fullscreen;
 
-	gtk_window_get_position (GTK_WINDOW (window->app),
-				 &main_window_x,
-				 &main_window_y);
-
-	gtk_widget_hide (window->app);
+	gtk_window_set_screen (GTK_WINDOW (fullscreen->window), gtk_widget_get_screen (window->app));
 	gtk_window_present (GTK_WINDOW (fullscreen->window));
 
 	window->fullscreen = TRUE;
@@ -970,10 +969,11 @@ fullscreen_start (FullScreen   *fullscreen,
 					      FALSE),
 			     GDK_NONE);
 
-	if (! eel_gconf_get_boolean (PREF_BLACK_BACKGROUND))
-		image_viewer_set_black_background (IMAGE_VIEWER (fullscreen->viewer), TRUE);
 	gtk_widget_reparent (window->viewer, fullscreen->window); 
 
+	if (! eel_gconf_get_boolean (PREF_BLACK_BACKGROUND, FALSE))
+		image_viewer_set_black_background (IMAGE_VIEWER (fullscreen->viewer), TRUE);
+
 	/* capture keyboard events. */
 
 	if (! fullscreen->wm_state_fullscreen_support) {
@@ -1033,9 +1033,10 @@ fullscreen_stop (FullScreen *fullscreen)
 	if (fullscreen->mouse_hide_id)
 		g_source_remove (fullscreen->mouse_hide_id);
 
-	if (! eel_gconf_get_boolean (PREF_BLACK_BACKGROUND))
+	if (! eel_gconf_get_boolean (PREF_BLACK_BACKGROUND, FALSE))
 		image_viewer_set_black_background (IMAGE_VIEWER (fullscreen->viewer), FALSE);
 
+	gtk_widget_hide (fullscreen->window);
 	wmspec_change_state (FALSE,
 			     fullscreen->window->window,
 			     gdk_atom_intern ("_NET_WM_STATE_FULLSCREEN", 
@@ -1065,7 +1066,7 @@ fullscreen_stop (FullScreen *fullscreen)
 
 	/* stop the slideshow if the user wants so. */
 
-	if (eel_gconf_get_boolean (PREF_SLIDESHOW_FULLSCREEN))
+	if (eel_gconf_get_boolean (PREF_SLIDESHOW_FULLSCREEN, TRUE))
 		window_stop_slideshow (window);
 
 	gtk_widget_reparent (fullscreen->viewer, window->viewer_container);
@@ -1074,10 +1075,6 @@ fullscreen_stop (FullScreen *fullscreen)
 
 	gtk_widget_show_all (window->app);
 
-	gtk_window_move (GTK_WINDOW (window->app),
-			 main_window_x,
-			 main_window_y);
-
 	/* restore widgets visiblity */
 
 	window_set_preview_content (window, window->preview_content);
@@ -1087,8 +1084,4 @@ fullscreen_stop (FullScreen *fullscreen)
 		window_show_sidebar (window);
 	else 
 		window_hide_sidebar (window);
-
-	/**/
-
-	gtk_widget_hide (fullscreen->window);
 }
