@@ -75,12 +75,13 @@ typedef struct {
 	GtkWidget          *viewer_vscr;
 	GtkWidget          *viewer_hscr;
 	GtkWidget          *viewer_event_box;
-	GtkWidget          *go_back_combo_button;
+	GtkWidget          *go_back_toolbar_button;
+	GtkWidget          *show_folders_toolbar_button;
+	GtkWidget          *show_catalog_toolbar_button;
 	GtkWidget          *popup_menu;
 
 	GtkWidget          *image_comment;
-	GtkWidget          *image_exif_view;
-	GtkListStore       *image_exif_model;
+	GtkWidget          *exif_data_viewer;
 
 	GtkWidget          *progress;              /* statusbar widgets. */
 	GtkWidget          *image_info;
@@ -143,7 +144,6 @@ typedef struct {
 						 * the image is not from a 
 						 * catalog. */
 
-	int                 freeze_toggle_handler;
 	gfloat              dir_load_progress;
 	int                 activity_ref;       /* when > 0 some activity
 						 * is present. */
@@ -162,6 +162,7 @@ typedef struct {
 	guint               sel_change_timeout;
 	guint               busy_cursor_timeout;
 	guint               auto_load_timeout;
+	guint               update_layout_timeout;
 
 	GThumbPreloader    *preloader;
 
@@ -266,6 +267,9 @@ void            window_image_set_modified           (GThumbWindow *window,
 
 gboolean        window_image_get_modified           (GThumbWindow *window);
 
+void            window_save_pixbuf                  (GThumbWindow *window,
+						     GdkPixbuf    *pixbuf);
+
 /* functions used to notify a change. */
 
 void            window_notify_files_created         (GThumbWindow *window,
@@ -331,8 +335,6 @@ void            window_add_monitor                  (GThumbWindow *window);
 
 void            window_remove_monitor               (GThumbWindow *window);
 
-void            window_sync_menu_with_preferences   (GThumbWindow *window);
-
 void            window_exec_pixbuf_op               (GThumbWindow *window,
 						     GthPixbufOp  *pixop);
 
